==> haskell-doclayout-0.3.0.2-2-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-doclayout.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 doclayout
version:              0.3.0.2
visibility:           public
id:                   doclayout-0.3.0.2-Jk8R5Abcyi59Cb8zuDXdH6
key:                  doclayout-0.3.0.2-Jk8R5Abcyi59Cb8zuDXdH6
license:              BSD-3-Clause
copyright:            2016-19 John MacFarlane
maintainer:           jgm@berkeley.edu
author:               John MacFarlane
homepage:             https://github.com/jgm/doclayout
synopsis:             A prettyprinting library for laying out text documents.
description:
    doclayout is a prettyprinting library for laying out
    text documents, with several features not present
    in prettyprinting libraries designed for code.  It
    was designed for use in pandoc.

category:             Text
abi:                  21ae8aa786a5f8efe961027340da87fd
exposed:              True
exposed-modules:      Text.DocLayout
import-dirs:          /usr/lib/ghc-8.10.4/site-local/doclayout-0.3.0.2
library-dirs:         /usr/lib/ghc-8.10.4/site-local/doclayout-0.3.0.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.4/doclayout-0.3.0.2
hs-libraries:         HSdoclayout-0.3.0.2-Jk8R5Abcyi59Cb8zuDXdH6
depends:
    base-4.14.1.0 mtl-2.2.2 safe-0.3.19-AfrHSVViU1189qUhjBUb5b
    text-1.2.4.1

haddock-interfaces:   /usr/share/doc/haskell-doclayout/html/doclayout.haddock
haddock-html:         /usr/share/doc/haskell-doclayout/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-doclayout-0.3.0.2-5-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-doclayout.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 doclayout
version:              0.3.0.2
visibility:           public
id:                   doclayout-0.3.0.2-GKqxnIFksbiFO0yZ6RyYqL
key:                  doclayout-0.3.0.2-GKqxnIFksbiFO0yZ6RyYqL
license:              BSD-3-Clause
copyright:            2016-19 John MacFarlane
maintainer:           jgm@berkeley.edu
author:               John MacFarlane
homepage:             https://github.com/jgm/doclayout
synopsis:             A prettyprinting library for laying out text documents.
description:
    doclayout is a prettyprinting library for laying out
    text documents, with several features not present
    in prettyprinting libraries designed for code.  It
    was designed for use in pandoc.

category:             Text
abi:                  18af802c7a77e3d9a06e7ff3944e6c73
exposed:              True
exposed-modules:      Text.DocLayout
import-dirs:          /usr/lib/ghc-8.10.4/site-local/doclayout-0.3.0.2
library-dirs:         /usr/lib/ghc-8.10.4/site-local/doclayout-0.3.0.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.4/doclayout-0.3.0.2
hs-libraries:         HSdoclayout-0.3.0.2-GKqxnIFksbiFO0yZ6RyYqL
depends:
    base-4.14.1.0 mtl-2.2.2 safe-0.3.19-AfrHSVViU1189qUhjBUb5b
    text-1.2.4.1

haddock-interfaces:   /usr/share/doc/haskell-doclayout/html/doclayout.haddock
haddock-html:         /usr/share/doc/haskell-doclayout/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
